BluetoothDevice class

Constructors

BluetoothDevice.fromMap(Map map)
factory

Properties

address → String
The Bluetooth adress of the remote device.
final
alias → String?
The Friendly name of the device or, if set the locally modifiable alias name.
final
bondState → BluetoothBondState
Bonding state of the device.
final
hashCode → int
The hash code for this object.
no setteroverride
name → String?
The Broadcasted friendly name of the device.
final
rssi → int?
The RSSI (signal strength) value of the remote device as reported by the Bluetooth hardware.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → BluetoothDeviceType
Indicates the device type.
final
uuids → List<String>
The UUIDs supported by the device.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override